@@ -41,7 +41,7 @@ except ModuleNotFoundError as e:
 
     for module in (
         'crayons',
-        'fortnitepy==3.6.5',
+        'fortnitepy==3.6.8',
         'BenBotAsync',
         'FortniteAPIAsync',
         'sanic==21.6.2',
@@ -598,7 +598,7 @@ class SekkayBot(commands.Bot):
     async def status_change(self) -> None:
       if not len(self.friends) > 100:
         await asyncio.sleep(3)
-        await self.set_presence('🔴 {party_size}/16 | ' + f'{code} ')
+        await self.set_presence('🚫 PUBLIC SOON 🚫')
         await self.party.set_privacy(fortnitepy.PartyPrivacy.PRIVATE)
         self.loop.create_task(self.verify())
       else:
@@ -1241,6 +1241,11 @@ class SekkayBot(commands.Bot):
           await self.set_presence('🚫 PUBLIC SOON 🚫')
           await asyncio.sleep(3)
           await self.party.set_privacy(fortnitepy.PartyPrivacy.PRIVATE)
+
+        elif len(self.friends) == 1:
+          await self.set_presence('🚫 PUBLIC SOON 🚫')
+          await asyncio.sleep(3)
+          await self.party.set_privacy(fortnitepy.PartyPrivacy.PRIVATE)
           
         elif len(self.friends) >= 101 and len(self.friends) <= 200:
           await self.set_presence('💔 {party_size}/16 | ' + f'{code} ')
